yumwat change log
=================

0.4.3
-----

Released 13-09-27.

-   Patch prevents the same package from being detailed twice.

0.4.2
-----

Released 13-09-25. First PyPI release.

-   added uninstall script

0.4.1
-----

Reached 13-09-25.

-   PEP 8

-   Ran pythong on the project, despite the commit log reading that I ran
    yumwat on itself (sigh)

0.4.0
-----

Reached on 13-09-25.

-   Enable and disable yumwat and its timid mode via a single command

0.3.0
-----

Reached 13-09-21.

-   Timid mode and ``--wat`` option

0.2.0
-----

Reached 13-09-21.

-   ``--nowat`` option

0.1.0
-----

Reached 13-09-20.

-   Initial functionality reached: yumwat prints a list with package names
    and their descriptions

Pre-history
-----------

Yumwat was conceived and started a good while before 0.1.0 was considered
to have been reached.
